@@ -3,7 +3,7 @@ import os
 import mdt
 import mdt.features
 
-env = environ()
+env = Environ()
 mlib = mdt.Library(env)
 mlib.dihedral_classes.read('${LIB}/impgrp.lib')
 xray = mdt.features.XRayResolution(mlib, bins=[(0.51, 2.001, 'High res(2.0A)')])
